require 'uu/os/rest/dto'
require 'uu/os/uesuri'

module UU
  module UDS
    module Bucket

      # DTO representing bucket attributes.
      class BucketAttributes < UU::OS::REST::DTO

        # URI of the bucket.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :uri

        # Code of the bucket.
        # @param [String]
        # @return [String]
        attr_accessor :code

        # Name of the bucket.
        # @param [String]
        # @return [String]
        attr_accessor :name

        # Description of the bucket.
        # @param [String]
        # @return [String]
        attr_accessor :description

        # URI of application which is owner of this bucket.
        # @param [String, UU::OS::UESURI]
        # @return [UU::OS::UESURI]
        attr_accessor :application_uri

        # Bucket capacity (in megabytes).
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :capacity

        # Time (in minutes) after which blobs in this bucket will be automatically deleted.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :blob_timeout

        # Maximum allowed size of single blob (in megabytes).
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :max_blob_size

        # Maximum total size allowed to be stored by single user (in megabytes).
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :max_total_size_per_user

        # Maximum total size allowed to be stored by single application (in megabytes).
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :max_total_size_per_app

        # Total size (in bytes) of blobs in this bucket.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :total_blob_size

        # Total count of blobs in this bucket.
        # @param [Fixnum]
        # @return [Fixnum]
        attr_accessor :total_blob_count

        # If true, bucket is created only for specified AppBox (or App instance). In this case
        # only this particular application can manipulate with blobs. If false, bucket is public
        # for any application, but blob manipulation is restricted to user which created particular
        # blob.
        attr_accessor :restricted

        def uri
          attributes[:uri]
        end

        def uri=(val)
          if val
            attributes[:uri] = UU::OS::UESURI.new(val)
          else
            attributes[:uri] = nil
          end
        end

        def code
          attributes[:code]
        end

        def code=(val)
          attributes[:code] = val
        end

        def name
          attributes[:name]
        end

        def name=(val)
          attributes[:name] = val
        end

        def description
          attributes[:description]
        end

        def description=(val)
          attributes[:description] = val
        end

        def application_uri
          attributes[:applicationUri]
        end

        def application_uri=(val)
          if val
            attributes[:applicationUri] = UU::OS::UESURI.new(val)
          else
            attributes[:applicationUri] = nil
          end
        end

        def capacity
          attributes[:capacity]
        end

        def capacity=(val)
          attributes[:capacity] = val
        end

        def blob_timeout
          attributes[:blobTimeout]
        end

        def blob_timeout=(val)
          attributes[:blobTimeout] = val
        end

        def max_blob_size
          attributes[:maxBlobSize]
        end

        def max_blob_size=(val)
          attributes[:maxBlobSize] = val
        end

        def max_total_size_per_user
          attributes[:maxTotalSizePerUser]
        end

        def max_total_size_per_user=(val)
          attributes[:maxTotalSizePerUser] = val
        end

        def max_total_size_per_app
          attributes[:maxTotalSizePerApp]
        end

        def max_total_size_per_app=(val)
          attributes[:maxTotalSizePerApp] = val
        end

        def total_blob_size
          attributes[:totalBlobSize]
        end

        def total_blob_size=(val)
          attributes[:totalBlobSize] = val
        end

        def total_blob_count
          attributes[:totalBlobCount]
        end

        def total_blob_count=(val)
          attributes[:totalBlobCount] = val
        end

        def restricted
          attributes[:restricted]
        end

        def restricted=(val)
          attributes[:restricted] = val
        end

      end

    end
  end
end
